const ZeedhiAPIConstructor = require('zeedhi-functional-test-api');
const z = new ZeedhiAPIConstructor(browser, protractor);
const Helper = require('teknisa-helper');
const geral = new Helper.geral();
const loginPage = new Helper.login();
const protractorHelper = require('protractor-helper');
const j = require('../../../../json/leitorJson.po.js');
const tipoReceber = require('../../../../page-objects/parametrizacao/financeiro/titulosAReceber/tipoTituloReceber.po');

const tipoReceberGridId = '150631336237604912933575';
const empresaGridId = '15063133621083611323224';
const classifiacaoFinanceira = 'IMPOSTOS';
const historicoIntegracao = '0005';
const empresa = j.getValor('empresa').concat(' Teknisa');

const descricaoModificada = j.getValor('tituloReceber').concat(' uteis');
describe('Tela Tipo de Título a Receber', () => {
	beforeAll(() => {
		browser.get('http://erpteste.teknisa.com/login/');
		loginPage.login(j.getValor('login'), j.getValor('senha'));
		tipoReceber.abrir();
		protractorHelper.waitForElementVisibility(
			element(by.id(`grid-${tipoReceberGridId}`)), 5000);
	});

	afterAll(() => {
		geral.sair();
	});

	it('Deve acessar a tela de Tipo de Título a Receber', () => {
		expect(z.component.header.getTitle()).toBe('Tipo de Título a Receber');
	});

	it('Deve adicionar um Tipo de Título a Receber', () => {
		tipoReceber.adicionaTitulo(j.getValor('codigo'), j.getValor('tituloReceber'), j.getValor('contaContabil'),
			classifiacaoFinanceira, j.getValor('tituloReceber'), historicoIntegracao);
		geral.clickSalvar();
		geral.filterIt(j.getValor('codigo'));

		expect(geral.gridHasText(tipoReceberGridId, j.getValor('codigo')))
			.toEqual(j.getValor('codigo'));
		expect(geral.gridHasText(tipoReceberGridId, j.getValor('tituloReceber'), 1))
			.toEqual(j.getValor('tituloReceber'));
		expect(geral.gridHasText(tipoReceberGridId, classifiacaoFinanceira, 3))
			.toEqual(classifiacaoFinanceira);
	});

	it('Deve adicionar uma Empresa ao título', () => {
		tipoReceber.clickTitulo(j.getValor('codigo'));
		tipoReceber.adicionaEmpresa(empresa);
		geral.clickSalvar();

		expect(geral.gridHasText(empresaGridId, empresa, 1, true))
			.toEqual(empresa);
	});

	it('Deve editar um Tipo de Título a Receber', () => {
		tipoReceber.clickTitulo(j.getValor('codigo'));
		geral.clickEditar();
		tipoReceber.edita(descricaoModificada, j.getValor('contaContabil'), j.getValor('classificacaoFinanceira'),
			descricaoModificada, historicoIntegracao.replace(/.$/, '2'), 'Não');
		geral.clickSalvar();

		expect(geral.getTextoPorId('DSTPCTRECEB'))
			.toEqual(descricaoModificada);
		expect(geral.getTextoPorId('DSDEFACTREC'))
			.toEqual(descricaoModificada);
		expect(geral.getTextoPorId('DSCLASSFINA'))
			.toEqual(j.getValor('classificacaoFinanceira'));
	});

	it('Deve excluir uma Empresa do Título', () => {
		tipoReceber.clickTitulo(j.getValor('codigo'));
		tipoReceber.excluiEmpresa(empresa);
		protractorHelper.waitForElementVisibility(
			element(by.id(`grid-${empresaGridId}`)), 5000);

		expect(geral.gridHasText(empresaGridId, empresa, 1))
			.toBeUndefined();
	});

	it('Deve excluir um Título', () => {
		tipoReceber.clickTitulo(j.getValor('codigo'));
		tipoReceber.exclui();
		geral.filterIt(j.getValor('codigo'));

		expect(geral.gridHasText(tipoReceberGridId, descricaoModificada, 1))
			.toBeUndefined();
	});
});
